
#include <iostream>

#include "TSystem.h"
#include "TStyle.h"
#include "TROOT.h"
#include "TH1.h"
#include "TCanvas.h"

#include "TArtEventStore.h"

#include "TArtCalibNEBULA.hh"
#include "TArtNEBULAPla.hh"
#include "TArtNEBULAPlaPara.hh"
#include "TArtNEBULAParameters.hh"

void TestNEBULA()
{
  gStyle->SetOptStat(111111);
  gSystem->Load("libXMLParser.so");
  gSystem->Load("libanacore.so");
  gSystem->Load("libanasamurai.so");

  TArtCalibNEBULA *mynebula= new TArtCalibNEBULA();
  TArtNEBULAParameters *NEBULAParameters = new TArtNEBULAParameters();
  NEBULAParameters->LoadParameter("db/NEBULA.xml");

  TArtEventStore *estore = new TArtEventStore();
  estore->Open("ridf/test.ridf");

  TCanvas* canvas = TCanvas::MakeDefCanvas();
  TH1* hadc = new TH1I("hadc", "hist of adc", 4100, 0, 4100);
  TH1* htdc = new TH1I("htdc", "hist of tdc", 4100, 0, 4100);

  int neve = 0;
  while(estore->GetNextEvent() && neve<10000){
    std::cout << "\r AnaNEBULA: " << neve;

    mynebula->BeginEvent();
    mynebula->ReconstructData();

    Int_t NumNEBULAPla = mynebula->GetNumNEBULAPla();
    for(int i=0; i < NumNEBULAPla; ++i){
      TArtNEBULAPla* pla = mynebula->GetNEBULAPla(i);

      unsigned int adc = pla->GetRawADC();
      unsigned int tdc = pla->GetRawTDC();

      hadc->Fill(adc);
      htdc->Fill(tdc);

      const TArtNEBULAPlaPara* para = mynebula->GetNEBULAPlaPara(i);
//      std::cout << *para << std::endl;
//      std::cout << "ID:" << para->GetID() << std::endl;
//      std::cout << "Name:" << para->GetDetectorName() << std::endl;
//      std::cout << "Layer:" << para->GetLayer() << std::endl;
//      std::cout << "SubLayer:" << para->GetSubLayer() << std::endl;
    }

    mynebula->EndEvent();

    estore->ClearData();
    ++neve;
  }
  std::cout << std::endl;

  canvas->Divide(1,2);
  canvas->cd(1);
  hadc->Draw();
  canvas->cd(2);
  htdc->Draw();

  return;
}
