#ifndef _TARTNEBULAPLAPARA_H_
#define _TARTNEBULAPLAPARA_H_

#include "TArtMap.h"
#include "segidlist.h"

class TArtNEBULAPlaPara : public TObject
{
public:
  TArtNEBULAPlaPara(Int_t serialnumber, Int_t id, TString udlr, TString detname,
		    Int_t fpl, Int_t layer, Int_t sublayer,
		    Double_t tcal, Double_t toff, Double_t qcal, Double_t qped,
		    Int_t ignore)
    : TObject(),
      fSerialNumber(serialnumber), fID(id), fUDLR(udlr), fDetName(detname),
      fFpl(fpl), fLayer(layer), fSubLayer(sublayer),
      fTCal(tcal), fTOff(toff), fQCal(qcal), fQPed(qped),
      fIgnore(ignore){;}
  ~TArtNEBULAPlaPara(){;}

  Int_t GetSerialNumber() const {return fSerialNumber;}
  Int_t GetID() const {return fID;}
  const TString& GetUDLR() const {return fUDLR;}
  const TString& GetDetectorName() const {return fDetName;}
  Int_t GetFpl() const {return fFpl;}
  Int_t GetLayer() const {return fLayer;}
  Int_t GetSubLayer() const {return fSubLayer;}
  Double_t GetTCal() const {return fTCal;} 
  Double_t GetTOffset() const {return fTOff;} 
  Double_t GetQCal() const {return fQCal;} 
  Double_t GetQPed() const {return fQPed;} 
  //  Double_t GetPos(int i) const {return pos[i];} 
  Int_t GetIgnore() const {return fIgnore;}

  friend ostream& operator<<(ostream& out, const TArtNEBULAPlaPara& p){
    out << "SerialNumber: " << p.fSerialNumber << endl;
    out << "ID: " << p.fID << endl;
    out << "UDLR: " << p.fUDLR << endl;
    out << "DetectorName: " << p.fDetName << endl;
    out << "Focal Plane: " << p.fFpl << endl;
    out << "Layer: " << p.fLayer << endl;
    out << "SubLayer: " << p.fSubLayer << endl;
    out << "Time Calib: " << p.fTCal << endl;
    out << "Time Offset: " << p.fTOff << endl;
    out << "QDC Calib: " << p.fQCal << endl;
    out << "QDC pedestal: " << p.fQPed << endl;
    //    out << "Position: " <<p.pos[0]<< " " <<p.pos[1]<< " " <<p.pos[2]<< endl;
    out << "Ignore: " << p.fIgnore << endl;
    out << "Map of ADC: "  << p.fMapADC << endl;
    out << "Map of TDC: "  << p.fMapTDC << endl;
    out << endl;
    return out;
  }

  void SetMap(Int_t tgeo, Int_t tch, Int_t qgeo, Int_t qch)
  {
    fMapADC.SetMap(fFpl,42,qgeo,qch); 
    //    fMapADC.SetMap(fpl,NEBULAA,qgeo,qch); 
    //    cout << "ADC is mapped to " << fMapADC.GetMapInfo() << " " << fMapADC.GetName() << endl;
    fMapTDC.SetMap(fFpl,41,tgeo,tch); 
    //    fMapTDC.SetMap(fpl,NEBULAT,tgeo,tch); 
    //    cout << "TDC is mapped to " << fMapTDC.GetMapInfo() << " " << fMapTDC.GetName() << endl;
  }    

  const TArtRIDFMap& GetTDCMap() const {return fMapTDC;}
  const TArtRIDFMap& GetADCMap() const {return fMapADC;}

private:
  Int_t     fSerialNumber;
  Int_t     fID;
  TString   fUDLR;
  TString   fDetName;
  Int_t     fFpl;
  Int_t     fLayer;
  Int_t     fSubLayer;
  Double_t  fTCal;
  Double_t  fTOff;
  Double_t  fQCal;
  Double_t  fQPed;
  //  Double_t  pos[3]; // position in mm
  Int_t     fIgnore;

  TArtRIDFMap fMapTDC;
  TArtRIDFMap fMapADC;

  ClassDef(TArtNEBULAPlaPara,1);
};

#endif
